@@ -34,7 +34,7 @@ import ConfigParser
 from xml.dom import minidom, Node
 
 #Connect to osso service
-ctx = osso.Context('fSchedule', '0.1', False)
+ctx = osso.Context('fSchedule', '0.2', False)
 
 gtk.gdk.threads_init()
 
@@ -240,15 +240,24 @@ class Window(hildon.StackableWindow):
         self.ratingimages = []
         self.showlink = []
         self.movieid = []
+        self.scheduledate = ''
         self.exiting = False
+        #pointer to last beginning show button
+        self.pointer_show = None
+
+        #Showing empty window for user
+        self.show_all()
         
         #Make pannable area with vbox (we add later hbox into it)
+        self.pa = hildon.PannableArea()
+        self.pa.set_property("mov-mode", hildon.MOVEMENT_MODE_BOTH)
+        #We use callback to scroll pannable area after maping (not working right now)
+        self.pa.connect_after('map', self.on_map)
         self.vbox = gtk.VBox()
-        pa = hildon.PannableArea()
-        pa.add_with_viewport(self.vbox)
-        self.add(pa)
-        #Showing window
-        self.show_all()
+        self.vbox.show()
+        
+        self.pa.add_with_viewport(self.vbox)
+        self.add(self.pa)
                 
         #set hourglass running
         hildon.hildon_gtk_window_set_progress_indicator(self, 1) 
@@ -259,6 +268,18 @@ class Window(hildon.StackableWindow):
         #create rating thread so we can stop it when exiting 
         self.rthread = threading.Thread(target=self.get_ratings_thread, args="None")
 
+    def on_map(self, pannable_area):
+        #print 'started scrolling'
+        #print 'pa ', self.pa.flags()
+        #print 'button ', self.pointer_show.flags()
+        #Scroll to next show
+        pannable_area.scroll_to_child(self.pointer_show)
+        #print 'scrolled'
+        
+    def scroll_to(self, button):
+        #print 'scroll_to'
+        self.on_map(self.pa)
+        
     def close_window(self, widget, event, data=None):
         #terminating threads and waiting them to finish
         self.exiting = True
@@ -279,7 +300,6 @@ class Window(hildon.StackableWindow):
         banner = hildon.hildon_banner_show_information(self.win, "None", "Downloading Movie details")
 
     def open_url(self, button, data):
-        #ctx = osso.Context('fSchedule', '0.1', False)
         osso_rpc = osso.Rpc(ctx)
         osso_rpc.rpc_run("com.nokia.osso_browser","/com/nokia/osso_browser/request", 'com.nokia.osso_browser','load_url',rpc_args=(str(data),))
 
@@ -291,15 +311,16 @@ class Window(hildon.StackableWindow):
             #fill empty ratings
             for item in self.ratingurl:
                 self.ratingimages.append(gtk.Image())
+            #print 'before drawing'
             self.draw_schedule(args)
             #Show all that we have drawn
-            
+            #print 'after drawing and before show all'
             #If we are closing window then abort
             if (self.exiting): 
                 return
             else:    
                 self.show_all()
-
+            #print 'now starting ratings thread'
             #Start get raitings thread so we can show schedule earlyer
             self.rthread.start()
         except Exception, e:
@@ -313,7 +334,7 @@ class Window(hildon.StackableWindow):
         #Stop hourglass
         hildon.hildon_gtk_window_set_progress_indicator(self, 0)
         #Show all again
-        self.show_all()
+        #self.show_all()
 
     def equal_aud_names(self, args):
         maxwidth = 0
@@ -331,8 +352,16 @@ class Window(hildon.StackableWindow):
         #print "drawing buttons"
         vbox_left = gtk.VBox()
         vbox_right = gtk.VBox()
-        lbl_header = gtk.Label("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")")
-        self.vbox.pack_start(lbl_header)
+        #lbl_header = gtk.Label("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")")
+        lbl_butt = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
+        lbl_butt.set_text("Schedule for date " + self.scheduledate + " (fetched: " + time.strftime("%a, %d %b %Y %H:%M:%S", time.localtime()) + ")", "Press here for scrolling to current time")
+        lbl_butt.connect("clicked", self.scroll_to)
+        #lbl_butt.set_alignment(.5, .5, .5, .5)
+        lbl_butt.set_value_alignment(.5, 1)
+        self.pointer_show = lbl_butt
+        
+        self.vbox.pack_start(lbl_butt)
+        #self.vbox.pack_start(lbl_header)
         for index, item in enumerate(self.originalname):
              #If we are closing window then abort
              if (self.exiting): break
@@ -346,6 +375,10 @@ class Window(hildon.StackableWindow):
              butt_time.set_text(self.showtime[index], "")
              butt_time.connect("clicked", self.open_url, self.showlink[index])
              #butt_time.set_sensitive(1)
+             #Save last started show to pointer
+             if (self.showtime[index] < time.strftime("%H:%M", time.localtime())): 
+                 self.pointer_show = butt_time
+                 #print "%s" % (self.showtime[index])
 
              #butt_rating = hildon.Button(gtk.HILDON_SIZE_AUTO, hildon.BUTTON_ARRANGEMENT_VERTICAL)
              #butt_rating.add(self.ratingimages[index])
@@ -367,9 +400,11 @@ class Window(hildon.StackableWindow):
              vbox_left.pack_start(hbox)             
              vbox_right.pack_start(butt_title, 1, 1)
         hbox_all = gtk.HBox(False, 0)
-        hbox_all.pack_start(vbox_left, 0, 0) #put left bloc
-        hbox_all.pack_start(vbox_right, 1, 1) #put left bloc         
+        hbox_all.pack_start(vbox_left, 0, 0) #put left block
+        hbox_all.pack_start(vbox_right, 1, 1) #put right block         
         self.vbox.pack_start(hbox_all)
+        #self.vbox.show_all()
+        #self.show()
 
     def get_schedule(self, args):
         #print 'Downloading %s' % (args[0])
@@ -417,7 +452,8 @@ class Window(hildon.StackableWindow):
                     #image = gtk.Image()
                     #image.set_from_pixbuf(self.ratingimages[i].get_pixbuf())
                     #self.ratingimages.append(image)
-                self.show_all()    
+                #self.show_all()
+                self.ratingimages[index].show()    
         except Exception, e:
             print '%s\nError: %s' % (item,str(e))
             #Create a banner with a markup
@@ -537,8 +573,8 @@ class MainWindow(hildon.StackableWindow):
         dialog.set_transient_for(self)
         dialog.set_title("Preferences")
         btn_options = hildon.PickerButton(gtk.HILDON_SIZE_THUMB_HEIGHT, hildon.BUTTON_ARRANGEMENT_VERTICAL)
-        btn_options.set_title("Change Cinema")
-        #btn_options.set_alignment(.0, .5, 1., 0.)
+        btn_options.set_title("Change Company")
+        btn_options.set_value_alignment(.5, 1)
         selector = self.create_cinema_selector()
         btn_options.set_selector(selector)
         btn_options.connect("value-changed", self.value_changed)
@@ -599,7 +635,7 @@ class MainWindow(hildon.StackableWindow):
         self.show_all()
                    
 	def open_url(self, data):
-		osso_rpc = osso.Rpc(ctx)
+		#osso_rpc = osso.Rpc(ctx)
 		osso_rpc.rpc_run("com.nokia.osso_browser","/com/nokia/osso_browser/request", 'com.nokia.osso_browser','load_url',rpc_args=('http://www.forum.nokia.com/',))
 
     def read_config(self):
